Serialization APIs
^^^^^^^^^^^^^^^^^^

Pluggable JSON Decoder
~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: linaro_json.decoder
    :members:


Pluggable JSON Encoder 
~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: linaro_json.encoder
    :members:


Class Registry
~~~~~~~~~~~~~~

.. automodule:: linaro_json.proxy_registry
    :members:

